@@ -197,6 +197,14 @@ class TestDatabase(unittest.TestCase):
             self.assertFalse(dbdocxx is dbdocxx2)
             self.assertEqual(dbdocxx2.get(u'zz'), u'hello')
 
+    def test_removeURINone(self):
+        """
+        #356253: should be able to explicitly say "uri=None" when calling remove
+        """
+        with self.freshenDatabase() as db:
+            # this is odd, but it should work
+            db.remove(id=1, uri=None)
+
     def test_removeNulls(self):
         """
         Bug 321579: nulls should not kill addText
@@ -288,6 +296,9 @@ class TestDatabase(unittest.TestCase):
             cc = HCondition(u'*.**')
             self.assertRaises(TypeError, cc.addAttr, 'xxx')
 
+            # None as a kwarg should work (bug #356253)
+            c2 = HCondition(phrase=None)
+
             def attrSearch(expr, order=None, phrase=None):
                 if phrase:
                     cond = HCondition(phrase)
@@ -435,5 +446,22 @@ class TestDatabase(unittest.TestCase):
             self.assertEqual(len(db.search(cond)), 1)
 
 
+class TestMisc(unittest.TestCase):
+    """
+    Test misc. features of the package such as version string
+    """
+    def test_version(self):
+        """
+        __version__ and other release info can be found in copyright.py and
+        __init__.py
+
+        This doesn't really verify that copyright.py is generated correctly,
+        just that it exists and has the right contents.
+        """
+        from hypy import __version__ as version1
+        from hypy.copyright import __version__ as version2
+        self.assertEqual(version1, version2)
+
+
 if __name__ == '__main__':
     unittest.main()
